@@ -14,8 +14,8 @@
 #' dt: \tab time (s) between the current location and the next one\cr
 #' dist: \tab distance (m) between the current location and the next one
 #'   calculated using the Vincenty ellipsoid method.
-#'   See \link{distVincentyEllipsoid})\cr
-#' v: \tab speed (m.s^{-1})\cr
+#'   See \link[geosphere]{distVincentyEllipsoid})\cr
+#' v: \tab speed (m.s^-1)\cr
 #' dx: \tab the increase of the move in the x direction.\cr
 #' dy: \tab the increase of the move in the y direction.\cr
 #' theta: \tab the angle between each move and the x axis.\cr
@@ -99,7 +99,7 @@ xytb2ltraj<-function(xytb){
 	if(!requireNamespace("adehabitatLT", quietly = TRUE)){
 	 stop("adehabitatLT needed for this function to work. Please install it.",call.=FALSE)
 	}
-	if(class(xytb)!="xytb"){stop("the object is not an xytb object")}
+	if(!inherits(xytb,"xytb")){stop("the object is not an xytb object")}
 	if(nrow(xytb@xyt)==0){stop("the xyt slot seems empty")}
 	xyt<-xytb@xyt
 	track<-adehabitatLT::as.ltraj(xy=xyt[,c("x","y")],date=xyt$t,id=xyt$id,infolocs=xytb@b)
@@ -111,17 +111,19 @@ xytb2ltraj<-function(xytb){
 #' The function converts a ltraj object to a xytb object 
 #' (see  
 #' \url{https://CRAN.R-project.org/package=adehabitatLT}
-#' and \link{xytb-class}).
+#' and \link[m2b]{xytb-class}).
 #'
 #' @param ltraj A ltraj object
 #' @param desc General descriptor of the data
 #' @return A xytb object with behavioural information taken from the infolocs
 #' (aka ltraj object should correspond the an export of xytb object in ltraj).
 #' @examples
+#' \dontrun{ 
 #' #track_CAGA_005 is a dataset
 #' xytb<-xytb(track_CAGA_005,"a track",3,.5)
 #' ltraj<-xytb2ltraj(xytb)
 #' xytb2<-ltraj2xytb(ltraj,"a track")
+#' }
 #' @author Laurent Dubroca
 #' @name ltraj2xytb
 #' @export
@@ -169,7 +171,7 @@ xytb2hmm<-function(xytb){
 	if(!requireNamespace("moveHMM", quietly = TRUE)){
 	 stop("moveHMM needed for this function to work. Please install it.",call.=FALSE)
 	}
-	if(class(xytb)!="xytb"){stop("the object is not an xytb object")}
+	if(!inherits(xytb,"xytb")){stop("the object is not an xytb object")}
 	xy<-xytb@xyt
 	xy<-data.frame(ID=xy$id,x=xy$x,y=xy$y)
 	rez<-moveHMM::prepData(xy)
@@ -178,7 +180,6 @@ xytb2hmm<-function(xytb){
 
 #' internal test function for dev purposes
 #'
-#' blablablablbalalb
 #'
 #' @keywords internal
 test<-function(){
@@ -196,7 +197,7 @@ test<-function(){
 
 #' xytb class constructor
 #'
-#' The methods to build an xytb object (see \link{xytb-class} for the class
+#' The methods to build an xytb object (see \link[m2b]{xytb-class} for the class
 #' description).
 #' 
 #' @param object a data frame with 5 columns
@@ -231,7 +232,7 @@ test<-function(){
 #' 	information \code{dxyt} and
 #' 	\code{befdxyt}. \code{dxyt} contains statistical derivatives of speed, distance and
 #' 	relative angle calculated on moving windows given by the winsize
-#' 	parameters. Statistical derivatides are standard deviation, mean, median
+#' 	parameters. Statistical derivatives are standard deviation, mean, median
 #' 	absolute deviation and quantiles. Quantiles are defined by the
 #' 	\code{idquant}
 #' 	parameters. \code{befdxyt} contains \code{dxyt} values shifted back in
@@ -565,7 +566,7 @@ setMethod("plot",
 #' Build a random forest model on a xytb object, predicting behaviour using
 #' only the variables calculated at the time of observation (type `actual`) or
 #' using the variable shifted backwards in time (type `shifted`). Parameters
-#' are transfered to the randomForest or the rfcv functions of the randomForest
+#' are passed to the randomForest or the rfcv functions of the randomForest
 #' package if needed.
 #'
 #' @author Laurent Dubroca and Andréa Thiebault
@@ -578,7 +579,7 @@ setMethod("plot",
 #' @param colin boolean - remove colinearity among predictors (see the caret
 #' package for more details)
 #' @param varkeep character vector - the variables names in this vector are
-#' keeped in the model even if colinearity is found (usefull to keep 'classical'
+#' kept in the model even if colinearity is found (to keep 'classical'
 #' parameters and to help interpretation)
 #' @param zerovar boolean - remove near zero variance predictor (see the caret
 #' package for more details)
@@ -590,7 +591,7 @@ setMethod("plot",
 #' @param ntree number of trees in the random Forest (see the randomForest
 #' package for more details)
 #' @param importance boolean (see the randomForest package for more details)
-#' @param ... other arguements passed to randonForest or rfcv
+#' @param ... other arguments passed to randomForest or rfcv
 #'
 #' @examples
 #' #track_CAGA_005 is dataset
@@ -616,14 +617,17 @@ setMethod("plot",
 modelRF<-function(xytb,type=c("actual","shifted"),nob="-1",
 		  colin=TRUE,varkeep=c("v","dist","thetarel"),
 		  zerovar=TRUE,rfcv=FALSE,ntree=501,importance=TRUE,...){
-	if(class(xytb)!="xytb"){ stop("invalid xytb object") }
+	if(!inherits(xytb,"xytb")){ stop("invalid xytb object") }
 	if(!type%in%c("actual","shifted") | length(type)!=1){
 	 stop("invalid type")
 	}
 	if(type=="actual"){ dat0<-cbind(xytb@b,xytb@dxyt,stringsAsFactors=F) }
 	if(type=="shifted"){ dat0<-cbind(xytb@b,xytb@befdxyt,stringsAsFactors=F) }
 	if(!nob%in%dat0$b){
-		stop("wrong no behavioural observation code")
+		warning("wrong no behavioural observation code")
+		idna<-as.numeric(attr(stats::na.omit(dat0),"na.action"))
+		dat0$b[dat0$b==nob]<-NA
+		initdat0<-dat0
 	}else{
 		idna<-as.numeric(attr(stats::na.omit(dat0),"na.action"))
 		dat0$b[dat0$b==nob]<-NA
@@ -640,7 +644,7 @@ modelRF<-function(xytb,type=c("actual","shifted"),nob="-1",
 		print("removing colinearity among predictors")
 		idcolin<-caret::findCorrelation(stats::cor(dat0),.9,verbose=F)
 		if(length(idcolin)>0){
-			print(paste(paste(varkeep,collapse=","),"keeped",collapse=" "))
+			print(paste(paste(varkeep,collapse=","),"kept",collapse=" "))
 			idcolin<-idcolin[which(!names(dat0)[idcolin]%in%varkeep)]
 			if(length(idcolin)>0){
 				print(paste(paste(names(dat0)[idcolin],collapse=","),
@@ -656,7 +660,7 @@ modelRF<-function(xytb,type=c("actual","shifted"),nob="-1",
 		print("removing near zero variance predictors")
 		idzerovar<-caret::nearZeroVar(dat0)
 		if(length(idzerovar)>0){
-			print(paste(paste(varkeep,collapse=","),"keeped",collapse=" "))
+			print(paste(paste(varkeep,collapse=","),"kept",collapse=" "))
 			idzerovar<-idzerovar[which(!names(dat0)[idzerovar]%in%varkeep)]
 			if(length(idzerovar)>0){
 				print(paste(paste(names(dat0)[idzerovar],collapse=","),
@@ -715,7 +719,7 @@ modelRF<-function(xytb,type=c("actual","shifted"),nob="-1",
 #' plot(modRF)
 #' @export
 extractRF<-function(xytb){
-	if(class(xytb)!="xytb"){ stop("invalid xytb object") }
+	if(!inherits(xytb,"xytb")){ stop("invalid xytb object") }
 	if(length(xytb@model)==0){stop("No model in the object, please run randomRF first",call.=F)}
 	modRF<-xytb@model
 	class(modRF)<-c("randomForest")
@@ -764,7 +768,7 @@ extractRF<-function(xytb){
 #' }
 #' @export
 resRF<-function(xytb,type="rf"){
-	if(class(xytb)!="xytb"){ stop("invalid xytb object") }
+	if(!inherits(xytb,"xytb")){ stop("invalid xytb object") }
 	if(length(xytb@model)==0){stop("No model in the object, please run randomRF first",call.=F)}
 	if(any(is.na(type)) | length(type)>1){stop("Wrong type",call.=F)}
 	if(!any(type%in%c("rfcv","rf","importance","confusion"))){stop("Wrong type",call.=F)}
@@ -854,7 +858,7 @@ resRF<-function(xytb,type="rf"){
 resB<-function(xytb,type="time",nob="-1"){
 	if(any(is.na(type)) | length(type)>1){stop("Wrong type",call.=F)}
 	if(!any(type%in%c("space","time","density"))){stop("Wrong type",call.=F)}
-	if(class(xytb)!="xytb"){ stop("invalid xytb object",call.=F) }
+	if(!inherits(xytb,"xytb")){ stop("invalid xytb object",call.=F) }
 	if(length(xytb@predb)==0){stop("No predicted behaviour in the object, please run randomRF first.",call.=F)}
 	if(length(xytb@b)==0){stop("No observed behaviour in the object, please build the xytb object wisely.",call.=F)}
 	if(!nob%in%xytb@b$b){ stop("Wrong no behavioural observation code",call.=F) }
